summaryrefslogtreecommitdiffstats
path: root/configdialog/kbfxconfigdlglayout.ui.h
diff options
context:
space:
mode:
Diffstat (limited to 'configdialog/kbfxconfigdlglayout.ui.h')
-rw-r--r--configdialog/kbfxconfigdlglayout.ui.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/configdialog/kbfxconfigdlglayout.ui.h b/configdialog/kbfxconfigdlglayout.ui.h
index b8a4d55..d57e9e0 100644
--- a/configdialog/kbfxconfigdlglayout.ui.h
+++ b/configdialog/kbfxconfigdlglayout.ui.h
@@ -187,7 +187,7 @@ void KbfxConfigDlgLayout::KbfxLayoutProperty_activated( int index )
break;
}
default: /* default action switch does nothing */
- kdDebug() << "Default action switch for saving layout changed..." << endl;
+ kdDebug() << "Default action switch for saving tqlayout changed..." << endl;
}
KbfxShowAll ();
@@ -426,7 +426,7 @@ void KbfxConfigDlgLayout::KbfxLayoutProperty_activated( int index )
break;
}
default: /* default action switch should never be reached */
- kdDebug() << "Default action switch for layout changed..." << endl;
+ kdDebug() << "Default action switch for tqlayout changed..." << endl;
}
}
@@ -465,7 +465,7 @@ void KbfxConfigDlgLayout::KbfxExportFileAction()
<< KbfxExportLayoutRcDialogURL
<< endl;
/* write layout theme configuration file */
KConfig *layoutconfig = new KConfig ( KbfxExportLayoutRcDialogURL );
layoutconfig->setGroup ( "KbfxButton" );
@@ -465,7 +465,7 @@ void KbfxConfigDlgLayout::KbfxExportFileAction()
<< KbfxExportLayoutRcDialogURL
<< endl;
- /* write layout theme configuration file */
+ /* write tqlayout theme configuration file */
KConfig *layoutconfig = new KConfig ( KbfxExportLayoutRcDialogURL );
layoutconfig->setGroup ( "KbfxButton" );